@@ -386,15 +386,14 @@ paint_shadow (cairo_t *cr, GtkStyle *style,
 		    GtkShadowType shadow_type,
 		    gdouble x, gdouble y, gdouble width, gdouble height)
 {
-	cairo_pattern_t *crp;
 	CairoColor bg, border;
+	CairoColor tl, bl;
 
 	ge_gdk_color_to_cairo (&style->bg[state_type], &bg);
 	ge_shade_color (&bg, OUTLINE_SHADE, &border); /* border */
 
 	x += 0.5; y += 0.5; width--; height--;
 
-	CairoColor tl, bl;
 	tl.r = 1; tl.g = 1; tl.b = 1; tl.a = 0.7;
 	bl.r = 0; bl.g = 0; bl.b = 0; bl.a = 0.2;
 
@@ -627,7 +626,7 @@ paint_scale_trough (cairo_t *cr, GtkStyle *style, GtkStateType state_type, GtkOr
 
 static void
 paint_progress_bar (cairo_t *cr, GtkStyle *style, GtkStateType state_type, GtkProgressBarOrientation orientation,
-		    gdouble x, gdouble y, gdouble width, gdouble height, gdouble fraction)
+		    gdouble x, gdouble y, gdouble width, gdouble height, gdouble fraction, CairoColor *base_color)
 {
 	cairo_pattern_t *crp;
 	CairoColor c1, c2;
@@ -635,8 +634,8 @@ paint_progress_bar (cairo_t *cr, GtkStyle *style, GtkStateType state_type, GtkPr
 	cairo_rectangle (cr, x, y, width, height);
 
 	ge_gdk_color_to_cairo (&style->base[GTK_STATE_SELECTED], &c1);
-	CRUX_DARK(c1, c2);
-	CRUX_LIGHT(c1, c1);
+	CRUX_DARK(*base_color, c2);
+	CRUX_LIGHT(*base_color, c1);
 	if (orientation == GTK_PROGRESS_LEFT_TO_RIGHT || orientation == GTK_PROGRESS_RIGHT_TO_LEFT)
 		crp = cairo_pattern_create_linear (x, y, x, y + height);
 	else
@@ -824,7 +823,7 @@ draw_shadow (GtkStyle *style,
 	debug ("draw_shadow: detail=%s state=%d shadow=%d x=%d y=%d w=%d h=%d\n",
 	        detail, state_type, shadow_type, x, y, width, height);
 
-	if (widget != NULL && GTK_WIDGET_HAS_FOCUS (widget))
+	if (widget != NULL && gtk_widget_has_focus (widget))
 		focused = TRUE;
 
 	if (widget && (GE_IS_COMBO (widget->parent) || GE_IS_COMBO_BOX_ENTRY (widget->parent)))
@@ -848,7 +847,6 @@ draw_shadow (GtkStyle *style,
 
 	if (widget && GTK_IS_SPIN_BUTTON (widget))
 	{
-		GtkWidget *button;
 		if (ge_widget_is_ltr (widget))
 			width += 2;
 		else
@@ -894,10 +892,9 @@ draw_box (GtkStyle *style,
 	if (DETAIL ("spinbutton"))
 	{
 		gboolean focused = FALSE;
-		GtkWidget *entry;
 		if (widget) {
-			state_type = GTK_WIDGET_STATE (widget);
-			focused = GTK_WIDGET_HAS_FOCUS (widget);
+			state_type = gtk_widget_get_state (widget);
+			focused = gtk_widget_has_focus (widget);
 		}
 		width += 3;
 		if (ge_widget_is_ltr (widget))
@@ -919,7 +916,7 @@ draw_box (GtkStyle *style,
 		gboolean focused = FALSE;
 
 		if (widget)
-			focused = GTK_WIDGET_HAS_FOCUS (widget);
+			focused = gtk_widget_has_focus (widget);
 
 		if (DETAIL ("spinbutton_down") || DETAIL ("spinbutton_up"))
 		{
@@ -948,8 +945,8 @@ draw_box (GtkStyle *style,
 
 			if ((entry = g_object_get_data ((GObject*) widget->parent, "entry")))
 			{
-				entry_focused = (GTK_WIDGET_HAS_FOCUS (entry));
-				state_type = GTK_WIDGET_STATE (entry);
+				entry_focused = (gtk_widget_has_focus (entry));
+				state_type = gtk_widget_get_state (entry);
 			}
 
 			if (state_type == GTK_STATE_INSENSITIVE)
@@ -1023,9 +1020,10 @@ draw_box (GtkStyle *style,
 		cairo_line_to (cr, cx, cy + ch);
 		cairo_stroke (cr);
 	}
-	else if (DETAIL ("bar"))
+	else if (DETAIL ("bar") || DETAIL ("entry-progress"))
 	{
 		GtkProgressBarOrientation orientation;
+		CairoColor base_color;
 		gdouble fraction = 0;
 		if (widget && GE_IS_PROGRESS_BAR (widget))
 		{
@@ -1034,7 +1032,13 @@ draw_box (GtkStyle *style,
 		}
 		else
 			orientation = GTK_PROGRESS_LEFT_TO_RIGHT;
-		paint_progress_bar (cr, style, state_type, orientation, x, y, width, height, fraction);
+
+		if (DETAIL ("bar"))
+			ge_gdk_color_to_cairo (&style->base[GTK_STATE_SELECTED], &base_color);
+		else
+			ge_gdk_color_to_cairo (&style->bg[state_type], &base_color);
+
+		paint_progress_bar (cr, style, state_type, orientation, x, y, width, height, fraction, &base_color);
 	}
 	else if (DETAIL ("trough") && GE_IS_SCALE (widget))
 	{
@@ -1736,12 +1740,12 @@ draw_extension (GtkStyle *style,
 			case GTK_POS_BOTTOM:
 				height++;
 				cairo_move_to (cr, x, y + height);
-				cairo_arc (cr, x + radius, y + radius, radius, M_PI, M_PI * 1.5);
+				cairo_arc (cr, x + radius, y + radius, radius, G_PI, G_PI * 1.5);
 				cairo_line_to (cr, x + width - radius, y);
 				cairo_set_source_rgba (cr, 1, 1, 1, 0.7);
 				cairo_stroke (cr);
 
-				cairo_arc (cr, x + width - radius, y + radius, radius, M_PI * 1.5, 0);
+				cairo_arc (cr, x + width - radius, y + radius, radius, G_PI * 1.5, 0);
 				cairo_line_to (cr, x + width, y + height - 1);
 				cairo_set_source_rgba (cr, 0, 0, 0, 0.2);
 				cairo_stroke (cr);
@@ -1750,13 +1754,13 @@ draw_extension (GtkStyle *style,
 			case GTK_POS_TOP:
 				y -= 1; height += 1;
 				cairo_move_to (cr, x, y);
-				cairo_arc_negative (cr, x + radius, y + height - radius, radius, M_PI, M_PI * 0.5);
+				cairo_arc_negative (cr, x + radius, y + height - radius, radius, G_PI, G_PI * 0.5);
 				cairo_set_source_rgba (cr, 1, 1, 1, 0.7);
 				cairo_stroke (cr);
 
 				cairo_move_to (cr, x + 1, y + height);
 				cairo_line_to (cr, x + width - radius, y + height);
-				cairo_arc_negative (cr, x + width - radius, y + height - radius, radius, M_PI * 0.5, 0);
+				cairo_arc_negative (cr, x + width - radius, y + height - radius, radius, G_PI * 0.5, 0);
 				cairo_line_to (cr, x + width, y);
 				cairo_set_source_rgba (cr, 0, 0, 0, 0.2);
 				cairo_stroke (cr);
@@ -1765,8 +1769,8 @@ draw_extension (GtkStyle *style,
 			case GTK_POS_LEFT:
 				x -= 1; width += 1;
 				cairo_move_to (cr, x, y);
-				cairo_arc (cr, x + width - radius, y + radius, radius, M_PI * 1.5, 0);
-				cairo_arc (cr, x + width - radius, y + height - radius, radius, 0, M_PI * 0.5);
+				cairo_arc (cr, x + width - radius, y + radius, radius, G_PI * 1.5, 0);
+				cairo_arc (cr, x + width - radius, y + height - radius, radius, 0, G_PI * 0.5);
 				cairo_set_source_rgba (cr, 1, 1, 1, 0.7);
 				cairo_stroke (cr);
 				
@@ -1779,8 +1783,8 @@ draw_extension (GtkStyle *style,
 			case GTK_POS_RIGHT:
 				width += 1;
 				cairo_move_to (cr, x + width, y);
-				cairo_arc_negative (cr, x + radius, y + radius, radius, M_PI * 1.5, M_PI);
-				cairo_arc_negative (cr, x + radius, y + height - radius, radius, M_PI, M_PI * 0.5);
+				cairo_arc_negative (cr, x + radius, y + radius, radius, G_PI * 1.5, G_PI);
+				cairo_arc_negative (cr, x + radius, y + height - radius, radius, G_PI, G_PI * 0.5);
 				cairo_set_source_rgba (cr, 1, 1, 1, 0.7);
 				cairo_stroke (cr);
 
@@ -1872,7 +1876,7 @@ draw_slider (GtkStyle *style,
 	/* dark */
 	CRUX_DARK (c2, c2);
 
-	if (widget != NULL && GTK_WIDGET_HAS_FOCUS (widget))
+	if (widget != NULL && gtk_widget_has_focus (widget))
 	{
 		ge_cairo_rounded_rectangle (cr, x+0.5, y+0.5, width-1.0, height-1.0, 2, CR_CORNER_ALL);
 	}
