@@ -2,19 +2,19 @@
 #include "thinice_rc_style.h"
 #include "thinice_style.h"
 
-G_MODULE_EXPORT void
+GE_EXPORT void
 theme_init (GTypeModule *module)
 {
-  thinice_rc_style_register_type (module);
-  thinice_style_register_type (module);
+  thinice_rc_style_register_types (module);
+  thinice_style_register_types (module);
 }
 
-G_MODULE_EXPORT void
+GE_EXPORT void
 theme_exit (void)
 {
 }
 
-G_MODULE_EXPORT GtkRcStyle *
+GE_EXPORT GtkRcStyle *
 theme_create_rc_style (void)
 {
   void *ptr;
